import {
  USER_LOGIN_SUCCESS,
  USER_LOGIN_FAILED,
  USER_LOGIN_ERROR,
  USER_SIGNUP_SUCCESS,
  USER_SIGNUP_FAILED,
  USER_SIGNUP_ERROR,
  USER_LOGOUT_SUCCESS,
  GET_USER_PROFILE_SUCCESS,
  GET_USER_PROFILE_ERROR,
} from "./types";
import { SERVER_URL, API_ENDPOINT, AUTH_ENDPOINT } from "../constant";
import axios from "axios";
import { history } from "../index";
import { toast } from "react-toastify";

//LOGIN-----------------------------
export const userLoginSuccess = (data) => {
  return {
    type: USER_LOGIN_SUCCESS,
    payload: data,
  };
};

export const userLoginFailed = (data) => {
  return {
    type: USER_LOGIN_FAILED,
    payload: data,
  };
};

export const userLoginError = (data) => {
  return {
    type: USER_LOGIN_ERROR,
    payload: data,
  };
};

export const userLogin = (user) => {
  const data = {
    email: user.email,
    password: user.password,
  };

  return (dispatch) => {
    return axios
      .post(`${SERVER_URL}/user/login`, data)
      .then((response) => {
        if (!response.data.result.username) {
          dispatch(userLoginFailed(response.data.result));
          return;
        }
        const headers = {
          username: response.data.result.username,
        };
        data.headers = headers;
        data.username = response.data.result.username;
        dispatch(userLoginFailed(""));
        dispatch(userLoginSuccess(data));
        toast.success("Loged successfully");
        history.push("/");
      })
      .catch((error) => {
        dispatch(userLoginFailed(error.message));
        toast.error(error.message, {
          position: "top-center",
        });
      });
  };
};

//LOGOUT-------------------------------------
export const userLogoutSuccess = () => {
  return {
    type: USER_LOGOUT_SUCCESS,
  };
};

export const userLogout = () => {
  return (dispatch) => {
    dispatch(userLogoutSuccess());
    history.push("/login");
  };
};

//SIGN UP-----------------------------
export const userSignUpSuccess = (data) => {
  return {
    type: USER_SIGNUP_SUCCESS,
    payload: data,
  };
};

export const userSignUpFailed = (data) => {
  return {
    type: USER_SIGNUP_FAILED,
    payload: data,
  };
};

export const userSignUpError = (data) => {
  return {
    type: USER_SIGNUP_ERROR,
    payload: data,
  };
};

export const userSignUp = (user) => {
  const data = {
    username: user.username,
    email: user.email,
    password: user.password,
  };
  return (dispatch) => {
    return axios
      .post(`${SERVER_URL}/user/register`, data)
      .then((response) => {
        const headers = {
          username: user.username,
        };
        data.headers = headers;
        dispatch(userSignUpError(""));
        dispatch(userSignUpSuccess(data));
        toast.success("Account Created Successfully");
        history.push("/");
      })
      .catch((error) => {
        dispatch(userSignUpError(error.response.data.message));
        toast.error(error.response.data.message, {
          position: "top-center",
        });
      });
  };
};
//GET PROFILE DETAILS-----------------------------
export const getProfileSuccess = (data) => {
  return {
    type: GET_USER_PROFILE_SUCCESS,
    payload: data,
  };
};

export const getProfileError = (data) => {
  return {
    type: GET_USER_PROFILE_ERROR,
    payload: data,
  };
};

export const getProfile = (header) => {
  return (dispatch) => {
    return axios
      .get(`${SERVER_URL}/${AUTH_ENDPOINT}/profile`, {
        headers: header,
      })
      .then((response) => {
        dispatch(getProfileError(""));
        dispatch(getProfileSuccess(response.data));
      })
      .catch((error) => {
        dispatch(getProfileError(error.message));
        toast.error(error.message, {
          position: "top-center",
        });
      });
  };
};
