import React, { useEffect, useState } from "react";
import { connect } from "react-redux";
import { getBlackList, addToBlackList } from "../../action/blacklist.actions";

import {
  CCard,
  CCardHeader,
  CCardBody,
  CRow,
  CCol,
  CDataTable,
  CBadge,
  CInput,
  CButton,
} from "@coreui/react";

const BlackList = (props) => {
  const fields = ["ip"];
  const [ip, setIp] = useState([]);

  useEffect(() => {
    props.onGetBlacklist();
  }, []);

  const handleAddToBlackList = (e) => {
    e.preventDefault();
    const ip_data = {
      ip: ip,
    };
    setIp("");
    props.onAddToBlackList(ip_data);
  };

  return (
    <CRow>
      <CCol xs="12" lg="8">
        <CCard>
          <CCardHeader>Black List</CCardHeader>
          <CCardBody>
            <CDataTable
              items={props.blacklist}
              fields={fields}
              itemsPerPage={10}
              pagination
              scopedSlots={{
                status: (item) => (
                  <td>
                    <CBadge color={"red"}>{item.status}</CBadge>
                  </td>
                ),
              }}
            />
          </CCardBody>
        </CCard>
      </CCol>
      <CCol xs="12" lg="4">
        <CCard>
          <CCardHeader>Add to Black List</CCardHeader>
          <CCardBody>
            <CInput
              type="text"
              id="ip"
              name="ip"
              value={ip}
              onChange={(e) => {
                setIp(e.target.value);
              }}
              placeholder="Enter an IP Address.."
              required
            />

            <CButton
              color={"info"}
              className="m-2"
              onClick={handleAddToBlackList}
            >
              Add
            </CButton>
          </CCardBody>
        </CCard>
      </CCol>
    </CRow>
  );
};

const mapStateToProps = (state) => {
  return {
    error: state.blacklistData.error || "",
    blacklist: state.blacklistData.blacklist || [],
  };
};

const mapDispatchToProps = (dispatch) => {
  return {
    onGetBlacklist: () => {
      dispatch(getBlackList());
    },
    onAddToBlackList: (ip) => {
      dispatch(addToBlackList(ip));
    },
  };
};

export default connect(mapStateToProps, mapDispatchToProps)(BlackList);
