import React, { useEffect, useState } from "react";
import { connect } from "react-redux";
import { getWhiteList, addToWhiteList } from "../../action/whitelist.actions";

import {
  CRow,
  CCol,
  CCard,
  CCardHeader,
  CCardBody,
  CDataTable,
  CBadge,
  CInput,
  CButton,
} from "@coreui/react";

const Whitelist = (props) => {
  const fields = ["ip"];

  const [ip, setIp] = useState("");

  useEffect(() => {
    props.onGetWhitelist();
  }, []);

  const handleAddToWhiteList = (e) => {
    e.preventDefault();
    const ip_data = {
      ip: ip,
    };
    setIp("");
    props.onAddToWhiteList(ip_data);
  };

  return (
    <CRow>
      <CCol xs="12" lg="8">
        <CCard>
          <CCardHeader>White List</CCardHeader>
          <CCardBody>
            <CDataTable
              items={props.whitelist}
              fields={fields}
              itemsPerPage={10}
              pagination
              scopedSlots={{
                status: (item) => (
                  <td>
                    <CBadge color={"red"}>{item.status}</CBadge>
                  </td>
                ),
              }}
            />
          </CCardBody>
        </CCard>
      </CCol>
      <CCol xs="12" lg="4">
        <CCard>
          <CCardHeader>Add to White List</CCardHeader>
          <CCardBody>
            <CInput
              type="text"
              placeholder="Add a valid IP Address.."
              autoComplete="ip"
              onChange={(e) => setIp(e.target.value)}
              required
            />
            <CButton
              color={"info"}
              className="m-2"
              onClick={handleAddToWhiteList}
            >
              Add
            </CButton>
          </CCardBody>
        </CCard>
      </CCol>
    </CRow>
  );
};

const mapStateToProps = (state) => {
  return {
    error: state.whitelistData.error || "",
    whitelist: state.whitelistData.whitelist || [],
  };
};

const mapDispatchToProps = (dispatch) => {
  return {
    onGetWhitelist: () => {
      dispatch(getWhiteList());
    },
    onAddToWhiteList: (ip) => {
      dispatch(addToWhiteList(ip));
    },
  };
};

export default connect(mapStateToProps, mapDispatchToProps)(Whitelist);
